==> haskell-success-0.2.6-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-Hrrda7aB2i7KSufsZcDUNu
key: success-0.2.6-Hrrda7aB2i7KSufsZcDUNu
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
abi: 6693b5a6fcec557f981360903d5e7dcd
exposed: True
exposed-modules:
    Success.Impure Success.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/success-0.2.6
hs-libraries: HSsuccess-0.2.6-Hrrda7aB2i7KSufsZcDUNu
depends:
    transformers-base-0.4.5.2-CJkbYH4N4LV8hMEohn0j3d
    monad-control-1.0.2.3-KD4Vsg6Ia0X5RLt8TMMDV6 mtl-2.2.2
    transformers-0.5.5.0 base-4.11.1.0
abi-depends: transformers-base-0.4.5.2-CJkbYH4N4LV8hMEohn0j3d=85e83aa98f31119a75b463e70412c07f
             monad-control-1.0.2.3-KD4Vsg6Ia0X5RLt8TMMDV6=c021194f497af7f0c1d884cb305008e2
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-success-0.2.6-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-7SunAklFaQR5dd94PG7iio
key: success-0.2.6-7SunAklFaQR5dd94PG7iio
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
abi: 2d0addbf9522678709964aaf471e15e8
exposed: True
exposed-modules:
    Success.Impure Success.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/success-0.2.6
hs-libraries: HSsuccess-0.2.6-7SunAklFaQR5dd94PG7iio
depends:
    transformers-base-0.4.5.2-AexAWi6e5nx6jQ9Vfwnuts
    monad-control-1.0.2.3-7JzgqOE5QdMK1n6qA1B9zU mtl-2.2.2
    transformers-0.5.5.0 base-4.11.1.0
abi-depends: transformers-base-0.4.5.2-AexAWi6e5nx6jQ9Vfwnuts=429c07af1089832867529f5d7ce0e624
             monad-control-1.0.2.3-7JzgqOE5QdMK1n6qA1B9zU=69e6cbcc316152f03e15a8ee01a3a4a0
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
